/**
  ******************************************************************************
  * @file    vk16d32_driver.c
  * @author  kevin_guo
  * @version V1.0.0
  * @date    06-05-2019
  * @brief   This file provides tuner io i2c vk16d32_driver functions.
  ******************************************************************************
  * @copy
  */ 
  
/* Includes ------------------------------------------------------------------*/
#include "vk16d32_driver.h"

/* extern variables ----------------------------------------------------------*/
unsigned char write_buf[12];
/* Private typedef -----------------------------------------------------------*/
/* Private define ------------------------------------------------------------*/
/* Private macro -------------------------------------------------------------*/
/* Private variables ---------------------------------------------------------*/
/* Private function prototypes -----------------------------------------------*/
/* Private function ----------------------------------------------------------*/

/*******************************************************************************
* Function Name  : VK16D32_delay_nus
* Description    : ʱ1uS
* Input          : n->ʱʱnuS
* Output         : None
* Return         : None
*******************************************************************************/
void VK16D32_delay_nus(unsigned int n)	   
{
	unsigned char i;
	while(n--)
	{
		i=10;
		while(i--)
		{//nopָݵƬӦ޸
			__nop();
		}
	}
}
/*******************************************************************************
* Function Name  : VK16D32_delay_nms
* Description    : ʱ1mS
* Input          : n->ʱʱnmS
* Output         : None
* Return         : None
*******************************************************************************/
void VK16D32_delay_nms(unsigned long int n)
{
	while(n--)
	{
		VK16D32_delay_nus(1000);
	}
}
//===============================================================================
//GPIO ģI2C 
/*************************************************************
*ƣVK16D32_I2CStart
*ܣI2Cʼź
*
*
*    עʱ߸ʱɸߵ͵䣬ʾI2Cʼź
**************************************************************/
void VK16D32_I2CStart( void )
{
  VK16D32_SDA_HIGH;
  VK16D32_delay_nus(1);
  VK16D32_SCL_HIGH;
  VK16D32_delay_nus(1);
  VK16D32_SDA_LOW;
  VK16D32_delay_nus(1);
}

/*************************************************************
*ƣVK16D32_I2CStop
*ܣI2Cֹͣź
*
*
*    עʱ߸ʱɵ͵ߵ䣬ʾI2Cֹͣź
**************************************************************/
void VK16D32_I2CStop( void )
{
  VK16D32_SDA_LOW;
  VK16D32_delay_nus(1);
  VK16D32_SCL_HIGH;
  VK16D32_delay_nus(1);
  VK16D32_SDA_HIGH;
  VK16D32_delay_nus(1);

  VK16D32_SCL_LOW;
}

/*************************************************************
*ƣVK16D32_I2CSlaveAck
*ܣI2Cӻ豸Ӧѯ
*
*
*    ע
**************************************************************/
unsigned char VK16D32_I2CSlaveAck( void )
{
  unsigned int TimeOut;
  unsigned char RetValue;
	
  
  VK16D32_SCL_LOW;
  VK16D32_delay_nus(1);
  VK16D32_SCL_HIGH;//9scl
  TimeOut = 10000;
  while( TimeOut-- > 0 )
  {
    if( VK16D32_SDA_IO==0 )//ȡack
    {
      RetValue = 0;
      break;
    }
    else
    {
      RetValue = 1;
    }
  }
  
  return RetValue;
}

/*************************************************************
*ƣVK16D32_I2CWriteByte
*ܣI2Cдһֽ
*
*
*    ע
**************************************************************/
void VK16D32_I2CWriteByte( unsigned char byte )
{
  unsigned char i;

  for( i=0; i<8; i++ )
  {
    VK16D32_SCL_LOW;
    if( 0X80 & byte )
      VK16D32_SDA_HIGH;
    else
      VK16D32_SDA_LOW;
    byte <<= 1;
    VK16D32_delay_nus(1);
    VK16D32_SCL_HIGH;
    VK16D32_delay_nus(1);		
  }
  VK16D32_SCL_LOW;
}

/*************************************************************
*: VK16D32WriteCmd
*: I2C_IOVK16D32дһֽ
*: cmd  д
*0: д1:д
*    ע
**************************************************************/
unsigned char VK16D32WriteCmd(unsigned char reg,unsigned char para )
{
	
  VK16D32_I2CStart();
	
  VK16D32_I2CWriteByte( VK16D32_DEVADDR|0x00 );
  if( 1 == VK16D32_I2CSlaveAck() )
  {
    return 1;
  }
  VK16D32_I2CWriteByte( reg );
  if( 1 == VK16D32_I2CSlaveAck() )
  {
    return 1;
  }
  VK16D32_I2CWriteByte( para );
  if( 1 == VK16D32_I2CSlaveAck() )
  {
    return 1;
  }
  VK16D32_I2CStop();
 
  return 0;
}

/*************************************************************
*: VK16D32WriteOneData
*: I2C_IOVK16D32д1ֽ
*: addr  дĵַ
*          data  д
*0: д1:д
*    ע
**************************************************************/
unsigned char VK16D32WriteOneData( unsigned char addr, unsigned char data )
{
	//START ź
  VK16D32_I2CStart();
  //SLAVEַ
  VK16D32_I2CWriteByte( VK16D32_DEVADDR|0x00 );
  if( 1 == VK16D32_I2CSlaveAck() )
  {
    return 1;
  }
	//ʾRAMַ
  VK16D32_I2CWriteByte( addr );
  if( 1 == VK16D32_I2CSlaveAck() )
  {
    return 1;
  }
	//ʾ
  VK16D32_I2CWriteByte( data );
  if( 1 == VK16D32_I2CSlaveAck() )
  {
    return 1;
  }
	//STOPź
  VK16D32_I2CStop();
  return 0;
}
/*************************************************************
*: VK16D32WriteNData
*: I2C_IOVK16D32д1ֽ/ַnֽ
*: daddr    дĵַ
*					 databuf  ݻ
*          num      дݸ
*0:      д1:д
*    ע
**************************************************************/
unsigned char VK16D32WriteNData( unsigned char addr, unsigned char* databuf, unsigned char num)
{
	unsigned char i;
	//STARTź		
  VK16D32_I2CStart();
	//SLAVEַ
  VK16D32_I2CWriteByte( VK16D32_DEVADDR|0x00 );
  if( 1 == VK16D32_I2CSlaveAck() )
  {
    return 1;
  }
	//дʾRAMַ
  VK16D32_I2CWriteByte( addr );
  if( 1 == VK16D32_I2CSlaveAck() )
  {
    return 1;
  }
	//numݵʾRAM
	for(i=0;i<num;i++)
	{
		VK16D32_I2CWriteByte(*databuf++);
		if( 1 == VK16D32_I2CSlaveAck() )
		{
			return 1;
		}
	}
	//STOPź
  VK16D32_I2CStop();

 
  return 0;
}
/*******************************************************************************
* Function Name  : Vk16d32_Init
* Description    : Vk16d32ʼ
* Input          : None
* Output         : None
* Return         : None
*******************************************************************************/
void Vk16d32_Init(void)
{	
	unsigned char i;
	//ͨߵƽͬӵƽת·
	//˺ݿͻƬӦ޸		 
	GPIO_SetMode(VK16D32_SCL_PORT, VK16D32_SCL_PIN, GPIO_MODE_OUTPUT);
	GPIO_SetMode(VK16D32_SDA_PORT, VK16D32_SDA_PIN, GPIO_MODE_QUASI);
	
	VK16D32_SCL_HIGH;
	VK16D32_SDA_HIGH; 	
	
	VK16D32WriteCmd(VK16D32_CTRL_REG,NOMAL_DISPOFF); //״̬ʾ	
	//0x00   0x01   0x02    0x03   0x04   0x05    0x06   0x07 
	//4.37mA 8.75mA 13.13mA 17.5mA 21.8mA 26.25mA 30.6mA 35mA 
	VK16D32WriteCmd(VK16D32_SEGI_REG,0x04); 	//ʾ0x00-0x0f
	//0x0b 0x0a 0x09 0x08 0x07 0x06 0x05 0x04 0x03 0x02 0x01 0x00
	//12λ 11λ 10λ  9λ  8λ  7λ  6λ  5λ  4λ  3λ  2λ  1λ
	VK16D32WriteCmd(VK16D32_GSCAN_REG,0x0b); 	//GRID	Ĭ12λ
	for(i=0;i<12;i++)
	{
		write_buf[i]=0x00;
	}
	VK16D32WriteNData(0x00,write_buf,12);   //ȫ
	VK16D32WriteCmd(VK16D32_CTRL_REG,NOMAL_DISPON); //״̬ʾ	
}
 
/*******************************************************************************
* Function Name  : VK16D32_Main
* Description    : vk16d32Գ
* Input          : None
* Output         : None
* Return         : None
*******************************************************************************/ 
void VK16D32_Main(void)
{   
	unsigned char i,j;
		 
	Vk16d32_Init();	  
	while(1)
	{
		for(i=0;i<12;i++)
		{
			write_buf[i]=0xff;
		}
	  VK16D32WriteNData(0x00,write_buf,12);   //ȫ
		VK16D32_delay_nms(1000); 
		for(i=0;i<12;i++)
		{
			write_buf[i]=0x00;
		}
		VK16D32WriteNData(0x00,write_buf,12);   //ȫ
		VK16D32_delay_nms(1000); 

		for(j=0;j<12;j++)
		{
			for(i=0;i<12;i++)
			{
				write_buf[i]=0x00;
			}
			write_buf[j]=0xff;
			VK16D32WriteNData(0x00,write_buf,12);
			VK16D32_delay_nms(1000); 
		}
		VK16D32_delay_nms(1000); 
		for(j=0;j<8;j+=1)
		{
			for(i=0;i<12;i+=1)
			{
				write_buf[i]=1<<j;
			}
			VK16D32WriteNData(0x00,write_buf,12);
			VK16D32_delay_nms(1000); 
		}
		for(i=0;i<12;i+=1)
		{
			write_buf[i]=0;
		}
		VK16D32WriteNData(0x00,write_buf,12);
		VK16D32_delay_nms(1000); 
		 		
		VK16D32WriteOneData(0x00, 0xff); 
		VK16D32_delay_nms(1000);  
		__nop();
	}
}   
/************************END OF FILE****/ 
